@@ -1,8 +1,11 @@
 # -*- coding: utf-8 -*-
-import sys, os, pkginfo, datetime
+import datetime
+import os
+import pkginfo
+import sys
 
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
-pkg_info = pkginfo.Develop(os.path.join(os.path.dirname(__file__),'..'))
+pkg_info = pkginfo.Develop(os.path.join(os.path.dirname(__file__), '..'))
 
 extensions = [
     'sphinx.ext.autodoc',
@@ -18,7 +21,7 @@ project = pkg_info.name
 copyright = '2008-%s Simplistix Ltd' % datetime.datetime.now().year
 version = release = pkg_info.version
 exclude_trees = ['_build']
-unused_docs = ['description']
+unused_docs = ['description.txt']
 pygments_style = 'sphinx'
 
 # Options for HTML output
@@ -30,7 +33,6 @@ htmlhelp_basename = project+'doc'
 
 # Options for LaTeX output
 latex_documents = [
-  ('index',project+'.tex', project+u' Documentation',
-   'Simplistix Ltd', 'manual'),
+    ('index', project+'.tex', project+u' Documentation',
+     'Simplistix Ltd', 'manual'),
 ]
-
